@@ -1,4 +1,4 @@
-# Copyright (c) 2008 - 2023, Ilan Schnell; All Rights Reserved
+# Copyright (c) 2008 - 2025, Ilan Schnell; All Rights Reserved
 """
 This package defines an object type which can efficiently represent
 a bitarray.  Bitarrays are sequence types and behave very much like lists.
@@ -9,16 +9,19 @@ Please find a description of this package at:
 
 Author: Ilan Schnell
 """
-from __future__ import absolute_import
-
-from bitarray._bitarray import (bitarray, decodetree, _sysinfo,
-                                _bitarray_reconstructor,
-                                get_default_endian, _set_default_endian,
-                                __version__)
+from collections import namedtuple
 
+from bitarray._bitarray import (
+    bitarray, decodetree, bits2bytes, _bitarray_reconstructor,
+    get_default_endian, _set_default_endian, _sysinfo,
+    BITARRAY_VERSION as __version__
+)
 
 __all__ = ['bitarray', 'frozenbitarray', 'decodetree', 'bits2bytes']
 
+BufferInfo = namedtuple('BufferInfo',
+                        ['address', 'nbytes', 'endian', 'padbits',
+                         'alloc', 'readonly', 'imported', 'exports'])
 
 class frozenbitarray(bitarray):
     """frozenbitarray(initializer=0, /, endian='big', buffer=None) -> \
@@ -54,23 +57,10 @@ and may therefore be used as a dictionary key.
     __ilshift__ = __irshift__ = __delitem__
 
 
-def bits2bytes(__n):
-    """bits2bytes(n, /) -> int
-
-Return the number of bytes necessary to store n bits.
-"""
-    import sys
-    if not isinstance(__n, (int, long) if sys.version_info[0] == 2 else int):
-        raise TypeError("integer expected")
-    if __n < 0:
-        raise ValueError("non-negative integer expected")
-    return (__n + 7) // 8
-
-
 def test(verbosity=1):
     """test(verbosity=1) -> TextTestResult
 
-Run self-test, and return unittest.runner.TextTestResult object.
+Run self-test, and return `unittest.runner.TextTestResult` object.
 """
     from bitarray import test_bitarray
     return test_bitarray.run(verbosity=verbosity)
